@@ -1,5 +1,5 @@
 package App::cpanminus;
-our $VERSION = "1.7037";
+our $VERSION = "1.7038";
 
 =encoding utf8
 
@@ -80,7 +80,7 @@ alternative URL, C<https://git.io/cpanm>
 
 =head1 DEPENDENCIES
 
-perl 5.8 or later.
+perl 5.8.1 or later.
 
 =over 4
 
